# slamifest

[![PyPI - Version](https://img.shields.io/pypi/v/slamifest.svg)](https://pypi.org/project/slamifest)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/slamifest.svg)](https://pypi.org/project/slamifest)

-----

`slamifest` is a command line tool to help work with Slack App Manifests.


**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install slamifest
```

## License

`slamifest` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
